aboutsummaryrefslogtreecommitdiff
path: root/src/rpcwallet.cpp
diff options
context:
space:
mode:
authorummjackson <[email protected]>2014-01-22 22:16:15 +1100
committerummjackson <[email protected]>2014-01-22 22:16:15 +1100
commitadd7f18c84efa15c123d8b4bb2465dc0307e596d (patch)
treeaf59700c0b9d4ba4025276f3edf905440e5764ba /src/rpcwallet.cpp
parentPatching git ignore. (diff)
downloaddiscoin-add7f18c84efa15c123d8b4bb2465dc0307e596d.tar.xz
discoin-add7f18c84efa15c123d8b4bb2465dc0307e596d.zip
Version update + p2pool fix for RPC help calls
Diffstat (limited to 'src/rpcwallet.cpp')
-rw-r--r--src/rpcwallet.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/src/rpcwallet.cpp b/src/rpcwallet.cpp
index ff0b6b29b..ec83914dc 100644
--- a/src/rpcwallet.cpp
+++ b/src/rpcwallet.cpp
@@ -102,7 +102,7 @@ Value getnewaddress(const Array& params, bool fHelp)
if (fHelp || params.size() > 1)
throw runtime_error(
"getnewaddress [account]\n"
- "Returns a new Litecoin address for receiving payments. "
+ "Returns a new Dogecoin address for receiving payments. "
"If [account] is specified (recommended), it is added to the address book "
"so payments received with the address will be credited to [account].");
@@ -169,7 +169,7 @@ Value getaccountaddress(const Array& params, bool fHelp)
if (fHelp || params.size() != 1)
throw runtime_error(
"getaccountaddress <account>\n"
- "Returns the current Litecoin address for receiving payments to this account.");
+ "Returns the current Dogecoin address for receiving payments to this account.");
// Parse the account first so we don't generate a key if there's an error
string strAccount = AccountFromValue(params[0]);
@@ -187,12 +187,12 @@ Value setaccount(const Array& params, bool fHelp)
{
if (fHelp || params.size() < 1 || params.size() > 2)
throw runtime_error(
- "setaccount <litecoinaddress> <account>\n"
+ "setaccount <dogecoinaddress> <account>\n"
"Sets the account associated with the given address.");
CBitcoinAddress address(params[0].get_str());
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Litecoin address");
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Dogecoin address");
string strAccount;
@@ -217,12 +217,12 @@ Value getaccount(const Array& params, bool fHelp)
{
if (fHelp || params.size() != 1)
throw runtime_error(
- "getaccount <litecoinaddress>\n"
+ "getaccount <dogecoinaddress>\n"
"Returns the account associated with the given address.");
CBitcoinAddress address(params[0].get_str());
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Litecoin address");
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Dogecoin address");
string strAccount;
map<CTxDestination, string>::iterator mi = pwalletMain->mapAddressBook.find(address.Get());
@@ -275,13 +275,13 @@ Value sendtoaddress(const Array& params, bool fHelp)
{
if (fHelp || params.size() < 2 || params.size() > 4)
throw runtime_error(
- "sendtoaddress <litecoinaddress> <amount> [comment] [comment-to]\n"
+ "sendtoaddress <dogecoinaddress> <amount> [comment] [comment-to]\n"
"<amount> is a real and is rounded to the nearest 0.00000001"
+ HelpRequiringPassphrase());
CBitcoinAddress address(params[0].get_str());
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Litecoin address");
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Dogecoin address");
// Amount
int64 nAmount = AmountFromValue(params[1]);
@@ -338,7 +338,7 @@ Value signmessage(const Array& params, bool fHelp)
{
if (fHelp || params.size() != 2)
throw runtime_error(
- "signmessage <litecoinaddress> <message>\n"
+ "signmessage <dogecoinaddress> <message>\n"
"Sign a message with the private key of an address");
EnsureWalletIsUnlocked();
@@ -373,7 +373,7 @@ Value verifymessage(const Array& params, bool fHelp)
{
if (fHelp || params.size() != 3)
throw runtime_error(
- "verifymessage <litecoinaddress> <signature> <message>\n"
+ "verifymessage <dogecoinaddress> <signature> <message>\n"
"Verify a signed message");
string strAddress = params[0].get_str();
@@ -410,14 +410,14 @@ Value getreceivedbyaddress(const Array& params, bool fHelp)
{
if (fHelp || params.size() < 1 || params.size() > 2)
throw runtime_error(
- "getreceivedbyaddress <litecoinaddress> [minconf=1]\n"
- "Returns the total amount received by <litecoinaddress> in transactions with at least [minconf] confirmations.");
+ "getreceivedbyaddress <dogecoinaddress> [minconf=1]\n"
+ "Returns the total amount received by <dogecoinaddress> in transactions with at least [minconf] confirmations.");
// Bitcoin address
CBitcoinAddress address = CBitcoinAddress(params[0].get_str());
CScript scriptPubKey;
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Litecoin address");
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Dogecoin address");
scriptPubKey.SetDestination(address.Get());
if (!IsMine(*pwalletMain,scriptPubKey))
return (double)0.0;
@@ -631,14 +631,14 @@ Value sendfrom(const Array& params, bool fHelp)
{
if (fHelp || params.size() < 3 || params.size() > 6)
throw runtime_error(
- "sendfrom <fromaccount> <tolitecoinaddress> <amount> [minconf=1] [comment] [comment-to]\n"
+ "sendfrom <fromaccount> <todogecoinaddress> <amount> [minconf=1] [comment] [comment-to]\n"
"<amount> is a real and is rounded to the nearest 0.00000001"
+ HelpRequiringPassphrase());
string strAccount = AccountFromValue(params[0]);
CBitcoinAddress address(params[1].get_str());
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Litecoin address");
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Dogecoin address");
int64 nAmount = AmountFromValue(params[2]);
int nMinDepth = 1;
if (params.size() > 3)
@@ -694,7 +694,7 @@ Value sendmany(const Array& params, bool fHelp)
{
CBitcoinAddress address(s.name_);
if (!address.IsValid())
- throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, string("Invalid Litecoin address: ")+s.name_);
+ throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, string("Invalid Dogecoin address: ")+s.name_);
if (setAddress.count(address))
throw JSONRPCError(RPC_INVALID_PARAMETER, string("Invalid parameter, duplicated address: ")+s.name_);
@@ -749,7 +749,7 @@ static CScript _createmultisig(const Array& params)
{
const std::string& ks = keys[i].get_str();
// Case 1: Litecoin address and we have full public key:
CBitcoinAddress address(ks);
if (pwalletMain && address.IsValid())
{
@@ -790,7 +790,7 @@ Value addmultisigaddress(const Array& params, bool fHelp)
{
string msg = "addmultisigaddress <nrequired> <'[\"key\",\"key\"]'> [account]\n"
"Add a nrequired-to-sign multisignature address to the wallet\"\n"
- "each key is a Litecoin address or hex-encoded public key\n"
+ "each key is a Dogecoin address or hex-encoded public key\n"
"If [account] is specified, assign address to [account].";
throw runtime_error(msg);
}
@@ -815,7 +815,7 @@ Value createmultisig(const Array& params, bool fHelp)
string msg = "createmultisig <nrequired> <'[\"key\",\"key\"]'>\n"
"Creates a multi-signature address and returns a json object\n"
"with keys:\n"
- "address : litecoin address\n"
+ "address : Dogecoin address\n"
"redeemScript : hex-encoded redemption script";
throw runtime_error(msg);
}
@@ -1470,7 +1470,7 @@ Value encryptwallet(const Array& params, bool fHelp)
// slack space in .dat files; that is bad if the old data is
// unencrypted private keys. So:
StartShutdown();
- return "wallet encrypted; Litecoin server stopping, restart to run with encrypted wallet. The keypool has been flushed, you need to make a new backup.";
+ return "wallet encrypted; Dogecoin server stopping, restart to run with encrypted wallet. The keypool has been flushed, you need to make a new backup.";
}
class DescribeAddressVisitor : public boost::static_visitor<Object>
@@ -1512,8 +1512,8 @@ Value validateaddress(const Array& params, bool fHelp)
{
if (fHelp || params.size() != 1)
throw runtime_error(
- "validateaddress <litecoinaddress>\n"
- "Return information about <litecoinaddress>.");
+ "validateaddress <dogecoinaddress>\n"
+ "Return information about <dogecoinaddress>.");
CBitcoinAddress address(params[0].get_str());
bool isValid = address.IsValid();
@@ -749,7 +749,7 @@ static CScript _createmultisig(const Array& params)
{
const std::string& ks = keys[i].get_str();
- // Case 1: Litecoin address and we have full public key:
+ // Case 1: Dogecoin address and we have full public key:
CBitcoinAddress address(ks);
if (pwalletMain && address.IsValid())